@@ -18,8 +18,8 @@ def on_event(request):
 
     body = request.body.decode()
     data = json.loads(body)
-    logger.info(f"event: {event_name} body: {body}")
+    logger.debug(f"event: {event_name}")
 
-    event_task(event_name, data)
+    event_task.delay(event_name, data)
 
     return HttpResponse(f"Event received! - {body}", status=202)
